@@ -29,23 +29,25 @@
 #include <QTemporaryFile>
 #include <QTimer>
 
+#include "about.h"
+#include "cmd.h"
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
-#include "cmd.h"
-#include "about.h"
+#include <chrono>
+
+using namespace std::chrono_literals;
 
 MainWindow::MainWindow(QWidget *parent) :
     QDialog(parent),
     ui(new Ui::MainWindow), lock_file(QStringLiteral("/var/lib/dpkg/lock")), reply(nullptr)
 {
-    qDebug().noquote() << qApp->applicationName() << "version:" << qApp->applicationVersion();
+    qDebug().noquote() << QApplication::applicationName() << "version:" << QApplication::applicationVersion();
     ui->setupUi(this);
     connect(ui->buttonAbout, &QPushButton::clicked, this, &MainWindow::buttonAbout_clicked);
     connect(ui->buttonHelp, &QPushButton::clicked, this, &MainWindow::buttonHelp_clicked);
     connect(ui->buttonOk, &QPushButton::clicked, this, &MainWindow::buttonOk_clicked);
 
     ui->stackedWidget->setCurrentIndex(0);
-
     // get arch info
     arch = cmd.getCmdOut(QStringLiteral("dpkg --print-architecture"), true);
 
@@ -62,15 +64,15 @@ MainWindow::~MainWindow()
 void MainWindow::updateStatus(const QString& msg, int val) {
     ui->labelDownload->setText(msg);
     ui->progressBar->setValue(val);
-    qApp->processEvents();
+    QApplication::processEvents();
 }
 
-// Check if online
-bool MainWindow::checkOnline()
+bool MainWindow::isOnline()
 {
     QNetworkRequest request;
-    request.setRawHeader("User-Agent", qApp->applicationName().toUtf8() + "/" +
-                         qApp->applicationVersion().toUtf8() + " (linux-gnu)");
+    request.setAttribute(QNetworkRequest::RedirectPolicyAttribute, QNetworkRequest::NoLessSafeRedirectPolicy);
+    request.setRawHeader("User-Agent", QApplication::applicationName().toUtf8() + "/" +
+                         QApplication::applicationVersion().toUtf8() + " (linux-gnu)");
 
     auto error = QNetworkReply::NoError;
     for (const QString &address : {"http://mxrepo.com", "http://google.com"}) {
@@ -82,7 +84,7 @@ bool MainWindow::checkOnline()
         connect(reply, QOverload<QNetworkReply::NetworkError>::of(&QNetworkReply::error),
                 [&error](QNetworkReply::NetworkError err) {error = err;} ); // errorOccured only in Qt >= 5.15
         connect(reply, QOverload<QNetworkReply::NetworkError>::of(&QNetworkReply::error), &loop, &QEventLoop::quit);
-        QTimer::singleShot(5000, &loop, [&loop, &error]() {error = QNetworkReply::TimeoutError; loop.quit();} ); // manager.setTransferTimeout(time) // only in Qt >= 5.15
+        QTimer::singleShot(5s, &loop, [&loop, &error]() {error = QNetworkReply::TimeoutError; loop.quit();} ); // manager.setTransferTimeout(time) // only in Qt >= 5.15
         loop.exec();
         reply->disconnect();
         if (error == QNetworkReply::NoError)
@@ -95,7 +97,7 @@ bool MainWindow::checkOnline()
 void MainWindow::buttonOk_clicked() {
     if (ui->stackedWidget->currentIndex() == 0) {
         setCursor(QCursor(Qt::WaitCursor));
-        if (!checkOnline()) {
+        if (!isOnline()) {
             QMessageBox::critical(this, tr("Error"),
                                   tr("Internet is not available, won't be able to download the list of packages"));
             setCursor(QCursor(Qt::ArrowCursor));
@@ -103,7 +105,7 @@ void MainWindow::buttonOk_clicked() {
         }
         installDebs(downloadDebs());
     } else {
-        qApp->quit();
+        QApplication::quit();
     }
 }
 
@@ -146,45 +148,43 @@ bool MainWindow::downloadFile(const QString &url, QFile &file)
 
 // download .deb codecs returns download path
 QString MainWindow::downloadDebs() {
-    QString path;
-    QString release;
-    QString url = QStringLiteral("http://deb-multimedia.org");
-
     //set progressBar and refresh
     ui->progressBar->setValue(0);
     ui->stackedWidget->setCurrentIndex(1);
-    qApp->processEvents();
+    QApplication::processEvents();
 
     // create temp folder and set it current
     if (!tempdir.isValid()) {
         QMessageBox::critical(this, tr("Error"), tr("Could not create temp directory. "));
         exit(EXIT_FAILURE);
     }
-    path = tempdir.path();
+    QString path = tempdir.path();
     QDir::setCurrent(path);
 
     // get release info
-    release = cmd.getCmdOut(QStringLiteral("grep VERSION= /etc/os-release |grep -Eo [a-z]+ "));
+    QString release = cmd.getCmdOut(QStringLiteral("grep VERSION= /etc/os-release |grep -Eo [a-z]+ "));
 
     int idx = 0;
     const int inc = 10;
-
     QTemporaryFile file;
+    QString url = QStringLiteral("http://deb-multimedia.org");
     updateStatus(tr("<b>Running command...</b><p>") + tr("downloading Packages.gz from 'main'"), idx += inc);
     downloadInfoAndPackage(url, release, QStringLiteral("main"), arch, file, QStringList{"libdvdcss2", "libtxc-dxtn0"}, idx += inc);
 
-    //download and install w32 or w64 codecs on x86 platforms
+    // download and install w32 or w64 codecs on x86 platforms
     if (arch == QLatin1String("amd64") || arch == QLatin1String("i386")){
         QTemporaryFile file_nonfree;
         updateStatus(tr("<b>Running command...</b><p>") + tr("downloading Packages.gz from 'non-free'"), idx += inc);
-        if (!downloadInfoAndPackage(url, release, QStringLiteral("non-free"), arch, file_nonfree, QStringList{"w.*codecs.*deb"}, idx += inc)) arch_flag = false;
+        if (!downloadInfoAndPackage(url, release, QStringLiteral("non-free"), arch, file_nonfree,
+                                    QStringList{"w.*codecs.*deb"}, idx += inc)) arch_flag = false;
     }
 
     // if 64 bit, also install 32 bit libtxc-dxtn0 package
     if (arch == QLatin1String("amd64")) {
         QTemporaryFile file_i386;
         updateStatus(tr("<b>Running command...</b><p>") + tr("downloading Packages.gz from i386 'main'"), idx += inc);
-        if (!downloadInfoAndPackage(url, release, QStringLiteral("main"), QStringLiteral("i386"), file_i386, QStringList{"libtxc-dxtn0"}, idx += inc)) i386_flag = false;
+        if (!downloadInfoAndPackage(url, release, QStringLiteral("main"), QStringLiteral("i386"), file_i386,
+                                    QStringList{"libtxc-dxtn0"}, idx += inc)) i386_flag = false;
     }
 
     updateStatus(tr("<b>Download Finished.</b>"), idx += inc);
@@ -199,6 +199,7 @@ bool MainWindow::downloadInfoAndPackage(const QString &url, const QString &relea
         return false;
     }
 
+    const int step = 10;
     for (const QString &search_deb : search_terms) {
         QString out = cmd.getCmdOut("zgrep ^Filename " + file.fileName() + " |grep " + search_deb + " |cut -d' ' -f2 |head -n1");
         if (out.isEmpty()) {
@@ -208,47 +209,39 @@ bool MainWindow::downloadInfoAndPackage(const QString &url, const QString &relea
             updateStatus(tr("<b>Running command...</b><p>") + "downloading: " + out, progress);
             downloadDeb(url, out);
         }
-        progress += 10;
+        progress += step;
     }
     return true;
 }
 
-// install downloaded .debs
 void MainWindow::installDebs(const QString& path) {
-    QDir dir;
     QDir::setCurrent(path);
-    bool error = false;
-
-    //filter *.deb file only
     QStringList filter;
     filter << QStringLiteral("*.deb");
+    QDir dir;
     dir.setNameFilters(filter);
 
     QStringList fileList = dir.entryList();
     ui->groupBox->setTitle(tr("Installing downloaded files"));
 
-    int size = fileList.size();
-    if (size == 0) {
+    if (fileList.isEmpty()) {
         QMessageBox::critical(this, tr("Error"), tr("No downloaded *.debs files found."));
-        qApp->exit(EXIT_FAILURE);
+        QApplication::exit(EXIT_FAILURE);
     }
 
     qDebug() << "filelist " << fileList;
 
     lock_file.unlock();
-    QString cmd_str_2;
-    if (arch_flag) {
-        cmd_str_2 = "dpkg --remove libtxc-dxtn-s2tc:" + arch;
-        cmd.run(cmd_str_2);
-    }
-    if (i386_flag) {
-        cmd_str_2 = QStringLiteral("dpkg --remove libtxc-dxtn-s2tc:i386");
-        cmd.run(cmd_str_2);
-    }
+    if (arch_flag)
+        cmd.run("dpkg --remove libtxc-dxtn-s2tc:" + arch);
+
+    if (i386_flag)
+        cmd.run(QStringLiteral("dpkg --remove libtxc-dxtn-s2tc:i386"));
 
     int idx = ui->progressBar->value();
     int inc = (ui->progressBar->maximum() - idx) / fileList.size();
 
+    bool error = false;
     for (const QString &file : fileList) {
         updateStatus(tr("<b>Installing...</b><p>") + file, idx += inc);
         if (!cmd.run("dpkg -i " + file)) {
@@ -270,19 +263,18 @@ void MainWindow::installDebs(const QString& path) {
     if (!error) {
         QMessageBox::information(this, tr("Finished"),
                                  tr("Codecs files have been downloaded and installed successfully."));
-        qApp->exit(EXIT_SUCCESS);
+        QApplication::exit(EXIT_SUCCESS);
     } else {
         QMessageBox::critical(this, tr("Error"),
                               tr("Process finished. Errors have occurred during the installation."));
-        qApp->exit(EXIT_FAILURE);
+        QApplication::exit(EXIT_FAILURE);
     }
 }
 
-// show about
 void MainWindow::buttonAbout_clicked() {
     this->hide();
     displayAboutMsgBox(tr("About MX Codecs"), "<p align=\"center\"><b><h2>" + this->windowTitle() +"</h2></b></p><p align=\"center\">" +
-                       tr("Version: ") + qApp->applicationVersion() + "</p><p align=\"center\"><h3>" +
+                       tr("Version: ") + QApplication::applicationVersion() + "</p><p align=\"center\"><h3>" +
                        tr("Simple codecs downloader for MX Linux") +
                        R"(</h3></p><p align="center"><a href="http://mxlinux.org">http://mxlinux.org</a><br /></p><p align="center">)" +
                        tr("Copyright (c) MX Linux") + "<br /><br /></p>",
@@ -290,13 +282,10 @@ void MainWindow::buttonAbout_clicked() {
     this->show();
 }
 
-// Help button clicked
 void MainWindow::buttonHelp_clicked() {
     QLocale locale;
     QString lang = locale.bcp47Name();
-
     QString url = QStringLiteral("file:///usr/share/doc/mx-codecs/mx-codecs.html");
-
     if (lang.startsWith(QLatin1String("fr")))
         url = QStringLiteral("https://mxlinux.org/french-wiki/help-files/help-mx-codecs-installer");
     displayDoc(url, tr("%1 Help").arg(this->windowTitle()), true);
